# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/apploadbalancer/v1/load_balancer_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/apploadbalancer/v1/load_balancer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import load_balancer_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2
from yandex.cloud.apploadbalancer.v1 import logging_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/apploadbalancer/v1/load_balancer_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/apploadbalancer/v1/load_balancer.proto\x1a-yandex/cloud/apploadbalancer/v1/logging.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x16GetLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x18ListLoadBalancersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"{\n\x19ListLoadBalancersResponse\x12\x45\n\x0eload_balancers\x18\x01 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.LoadBalancer\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x19\x44\x65leteLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1a\x44\x65leteLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"\xea\x05\n\x19UpdateLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x45\n\x0elistener_specs\x18\x06 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpec\x12L\n\x11\x61llocation_policy\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12K\n\x11\x61uto_scale_policy\x18\t \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\n \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x12\x19\n\x11\x61llow_zonal_shift\x18\x0b \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x1aUpdateLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"\xe5\x05\n\x19\x43reateLoadBalancerRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x17\n\tregion_id\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nnetwork_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x0elistener_specs\x18\x07 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpec\x12L\n\x11\x61llocation_policy\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x1a\n\x12security_group_ids\x18\t \x03(\t\x12K\n\x11\x61uto_scale_policy\x18\n \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\x0b \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x12\x19\n\x11\x61llow_zonal_shift\x18\x0c \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x1a\x43reateLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\":\n\x18StartLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"5\n\x19StartLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"9\n\x17StopLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x18StopLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"\x80\x01\n\x12\x41\x64\x64ListenerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12J\n\rlistener_spec\x18\x02 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpecB\x04\xe8\xc7\x31\x01\"F\n\x13\x41\x64\x64ListenerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\"K\n\x15RemoveListenerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x16RemoveListenerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\"\xb4\x01\n\x15UpdateListenerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12J\n\rlistener_spec\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpecB\x04\xe8\xc7\x31\x01\"I\n\x16UpdateListenerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\"\xc3\x02\n\x0b\x41\x64\x64ressSpec\x12^\n\x1a\x65xternal_ipv4_address_spec\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressSpecH\x00\x12^\n\x1ainternal_ipv4_address_spec\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.InternalIpv4AddressSpecH\x00\x12^\n\x1a\x65xternal_ipv6_address_spec\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressSpecH\x00\x42\x14\n\x0c\x61\x64\x64ress_spec\x12\x04\xc0\xc1\x31\x01\"*\n\x17\x45xternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"=\n\x17InternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"*\n\x17\x45xternalIpv6AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"}\n\x0c\x45ndpointSpec\x12K\n\raddress_specs\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.AddressSpecB\x06\x82\xc8\x31\x02>0\x12 \n\x05ports\x18\x02 \x03(\x03\x42\x11\xfa\xc7\x31\x07\x31-65535\x82\xc8\x31\x02>0\"\xe5\x02\n\x0cListenerSpec\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12M\n\x0e\x65ndpoint_specs\x18\x02 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.EndpointSpecB\x06\x82\xc8\x31\x02>0\x12=\n\x04http\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.HttpListenerH\x00\x12;\n\x03tls\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TlsListenerH\x00\x12\x41\n\x06stream\x18\x05 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.StreamListenerH\x00\x42\x10\n\x08listener\x12\x04\xc0\xc1\x31\x01\"w\n\x16GetTargetStatesRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0ftarget_group_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"^\n\x17GetTargetStatesResponse\x12\x43\n\rtarget_states\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TargetState\"\xc7\x01\n\x12\x41\x64\x64SniMatchRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rlistener_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0cserver_names\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x05 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"^\n\x13\x41\x64\x64SniMatchMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\x12\x16\n\x0esni_match_name\x18\x03 \x01(\t\"r\n\x15RemoveSniMatchRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rlistener_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0esni_match_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"a\n\x16RemoveSniMatchMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\x12\x16\n\x0esni_match_name\x18\x03 \x01(\t\"\xfb\x01\n\x15UpdateSniMatchRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rlistener_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1c\n\x0cserver_names\x18\x05 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x06 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"a\n\x16UpdateSniMatchMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\x12\x16\n\x0esni_match_name\x18\x03 \x01(\t\"\x89\x01\n!ListLoadBalancerOperationsRequest\x12&\n\x10load_balancer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListLoadBalancerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"R\n\x16StartZonalShiftRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\x08zone_ids\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\"E\n\x17StartZonalShiftMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t\"S\n\x17\x43\x61ncelZonalShiftRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\x08zone_ids\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\"F\n\x18\x43\x61ncelZonalShiftMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t\"\x88\x01\n\x13\x44isableZonesRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\x08zone_ids\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x37\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06\x31m-72h\"B\n\x14\x44isableZonesMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t\"N\n\x12\x45nableZonesRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\x08zone_ids\x18\x02 \x03(\tB\x06\x82\xc8\x31\x02>0\"A\n\x13\x45nableZonesMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x10\n\x08zone_ids\x18\x02 \x03(\t2\x89!\n\x13LoadBalancerService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.apploadbalancer.v1.GetLoadBalancerRequest\x1a-.yandex.cloud.apploadbalancer.v1.LoadBalancer\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/apploadbalancer/v1/loadBalancers/{load_balancer_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest\x1a:.yandex.cloud.apploadbalancer.v1.ListLoadBalancersResponse\")\x82\xd3\xe4\x93\x02#\x12!/apploadbalancer/v1/loadBalancers\x12\xc3\x01\n\x06\x43reate\x12:.yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2**\n\x1a\x43reateLoadBalancerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02&\"!/apploadbalancer/v1/loadBalancers:\x01*\x12\xd6\x01\n\x06Update\x12:.yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2**\n\x1aUpdateLoadBalancerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02\x39\x32\x34/apploadbalancer/v1/loadBalancers/{load_balancer_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12:.yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*3\n\x1a\x44\x65leteLoadBalancerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/apploadbalancer/v1/loadBalancers/{load_balancer_id}\x12\xd6\x01\n\x05Start\x12\x39.yandex.cloud.apploadbalancer.v1.StartLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*)\n\x19StartLoadBalancerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02<\":/apploadbalancer/v1/loadBalancers/{load_balancer_id}:start\x12\xd2\x01\n\x04Stop\x12\x38.yandex.cloud.apploadbalancer.v1.StopLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*(\n\x18StopLoadBalancerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02;\"9/apploadbalancer/v1/loadBalancers/{load_balancer_id}:stop\x12\xd9\x01\n\x0b\x41\x64\x64Listener\x12\x33.yandex.cloud.apploadbalancer.v1.AddListenerRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*#\n\x13\x41\x64\x64ListenerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addListener:\x01*\x12\xe5\x01\n\x0eRemoveListener\x12\x36.yandex.cloud.apploadbalancer.v1.RemoveListenerRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*&\n\x16RemoveListenerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeListener:\x01*\x12\xe5\x01\n\x0eUpdateListener\x12\x36.yandex.cloud.apploadbalancer.v1.UpdateListenerRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*&\n\x16UpdateListenerMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateListener:\x01*\x12\xe2\x01\n\x0b\x41\x64\x64SniMatch\x12\x33.yandex.cloud.apploadbalancer.v1.AddSniMatchRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*,\n\x13\x41\x64\x64SniMatchMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addSniMatch:\x01*\x12\xef\x01\n\x0eUpdateSniMatch\x12\x36.yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*/\n\x16UpdateSniMatchMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateSniMatch:\x01*\x12\xef\x01\n\x0eRemoveSniMatch\x12\x36.yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*/\n\x16RemoveSniMatchMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeSniMatch:\x01*\x12\xf4\x01\n\x0fGetTargetStates\x12\x37.yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest\x1a\x38.yandex.cloud.apploadbalancer.v1.GetTargetStatesResponse\"n\x82\xd3\xe4\x93\x02h\x12\x66/apploadbalancer/v1/loadBalancers/{load_balancer_id}/targetStates/{backend_group_id}/{target_group_id}\x12\xe2\x01\n\x0eListOperations\x12\x42.yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest\x1a\x43.yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/apploadbalancer/v1/loadBalancers/{load_balancer_id}/operations\x12\xec\x01\n\x0fStartZonalShift\x12\x37.yandex.cloud.apploadbalancer.v1.StartZonalShiftRequest\x1a!.yandex.cloud.operation.Operation\"}\x88\x02\x01\xb2\xd2*\'\n\x17StartZonalShiftMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02I\"D/apploadbalancer/v1/loadBalancers/{load_balancer_id}:startZonalShift:\x01*\x12\xf0\x01\n\x10\x43\x61ncelZonalShift\x12\x38.yandex.cloud.apploadbalancer.v1.CancelZonalShiftRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\x88\x02\x01\xb2\xd2*(\n\x18\x43\x61ncelZonalShiftMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02J\"E/apploadbalancer/v1/loadBalancers/{load_balancer_id}:cancelZonalShift:\x01*\x12\xdd\x01\n\x0c\x44isableZones\x12\x34.yandex.cloud.apploadbalancer.v1.DisableZonesRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*$\n\x14\x44isableZonesMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02\x46\"A/apploadbalancer/v1/loadBalancers/{load_balancer_id}:disableZones:\x01*\x12\xd9\x01\n\x0b\x45nableZones\x12\x33.yandex.cloud.apploadbalancer.v1.EnableZonesRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*#\n\x13\x45nableZonesMetadata\x12\x0cLoadBalancer\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:enableZones:\x01*Bz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _globals['_GETLOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_GETLOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTLOADBALANCERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DELETELOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_DELETELOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATELOADBALANCERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATELOADBALANCERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATELOADBALANCERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATELOADBALANCERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?'
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['region_id']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['region_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['network_id']._loaded_options = None
  _globals['_CREATELOADBALANCERREQUEST'].fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTLOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_STARTLOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_STOPLOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_STOPLOADBALANCERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDLISTENERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_ADDLISTENERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDLISTENERREQUEST'].fields_by_name['listener_spec']._loaded_options = None
  _globals['_ADDLISTENERREQUEST'].fields_by_name['listener_spec']._serialized_options = b'\350\3071\001'
  _globals['_REMOVELISTENERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_REMOVELISTENERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVELISTENERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REMOVELISTENERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATELISTENERREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_UPDATELISTENERREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATELISTENERREQUEST'].fields_by_name['listener_spec']._loaded_options = None
  _globals['_UPDATELISTENERREQUEST'].fields_by_name['listener_spec']._serialized_options = b'\350\3071\001'
  _globals['_ADDRESSSPEC'].oneofs_by_name['address_spec']._loaded_options = None
  _globals['_ADDRESSSPEC'].oneofs_by_name['address_spec']._serialized_options = b'\300\3011\001'
  _globals['_ENDPOINTSPEC'].fields_by_name['address_specs']._loaded_options = None
  _globals['_ENDPOINTSPEC'].fields_by_name['address_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_ENDPOINTSPEC'].fields_by_name['ports']._loaded_options = None
  _globals['_ENDPOINTSPEC'].fields_by_name['ports']._serialized_options = b'\372\3071\0071-65535\202\3101\002>0'
  _globals['_LISTENERSPEC'].oneofs_by_name['listener']._loaded_options = None
  _globals['_LISTENERSPEC'].oneofs_by_name['listener']._serialized_options = b'\300\3011\001'
  _globals['_LISTENERSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_LISTENERSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_LISTENERSPEC'].fields_by_name['endpoint_specs']._loaded_options = None
  _globals['_LISTENERSPEC'].fields_by_name['endpoint_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_GETTARGETSTATESREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_GETTARGETSTATESREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_GETTARGETSTATESREQUEST'].fields_by_name['backend_group_id']._loaded_options = None
  _globals['_GETTARGETSTATESREQUEST'].fields_by_name['backend_group_id']._serialized_options = b'\350\3071\001'
  _globals['_GETTARGETSTATESREQUEST'].fields_by_name['target_group_id']._loaded_options = None
  _globals['_GETTARGETSTATESREQUEST'].fields_by_name['target_group_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['listener_name']._loaded_options = None
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['listener_name']._serialized_options = b'\350\3071\001'
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['server_names']._loaded_options = None
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['server_names']._serialized_options = b'\202\3101\002>0'
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['handler']._loaded_options = None
  _globals['_ADDSNIMATCHREQUEST'].fields_by_name['handler']._serialized_options = b'\350\3071\001'
  _globals['_REMOVESNIMATCHREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_REMOVESNIMATCHREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVESNIMATCHREQUEST'].fields_by_name['listener_name']._loaded_options = None
  _globals['_REMOVESNIMATCHREQUEST'].fields_by_name['listener_name']._serialized_options = b'\350\3071\001'
  _globals['_REMOVESNIMATCHREQUEST'].fields_by_name['sni_match_name']._loaded_options = None
  _globals['_REMOVESNIMATCHREQUEST'].fields_by_name['sni_match_name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['listener_name']._loaded_options = None
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['listener_name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['server_names']._loaded_options = None
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['server_names']._serialized_options = b'\202\3101\002>0'
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['handler']._loaded_options = None
  _globals['_UPDATESNIMATCHREQUEST'].fields_by_name['handler']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_STARTZONALSHIFTREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_STARTZONALSHIFTREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTZONALSHIFTREQUEST'].fields_by_name['zone_ids']._loaded_options = None
  _globals['_STARTZONALSHIFTREQUEST'].fields_by_name['zone_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_CANCELZONALSHIFTREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_CANCELZONALSHIFTREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_CANCELZONALSHIFTREQUEST'].fields_by_name['zone_ids']._loaded_options = None
  _globals['_CANCELZONALSHIFTREQUEST'].fields_by_name['zone_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_DISABLEZONESREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_DISABLEZONESREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_DISABLEZONESREQUEST'].fields_by_name['zone_ids']._loaded_options = None
  _globals['_DISABLEZONESREQUEST'].fields_by_name['zone_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_DISABLEZONESREQUEST'].fields_by_name['duration']._loaded_options = None
  _globals['_DISABLEZONESREQUEST'].fields_by_name['duration']._serialized_options = b'\372\3071\0061m-72h'
  _globals['_ENABLEZONESREQUEST'].fields_by_name['load_balancer_id']._loaded_options = None
  _globals['_ENABLEZONESREQUEST'].fields_by_name['load_balancer_id']._serialized_options = b'\350\3071\001'
  _globals['_ENABLEZONESREQUEST'].fields_by_name['zone_ids']._loaded_options = None
  _globals['_ENABLEZONESREQUEST'].fields_by_name['zone_ids']._serialized_options = b'\202\3101\002>0'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/apploadbalancer/v1/loadBalancers/{load_balancer_id}'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/apploadbalancer/v1/loadBalancers'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateLoadBalancerMetadata\022\014LoadBalancer\202\323\344\223\002&\"!/apploadbalancer/v1/loadBalancers:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateLoadBalancerMetadata\022\014LoadBalancer\202\323\344\223\002924/apploadbalancer/v1/loadBalancers/{load_balancer_id}:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteLoadBalancerMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/apploadbalancer/v1/loadBalancers/{load_balancer_id}'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*)\n\031StartLoadBalancerMetadata\022\014LoadBalancer\202\323\344\223\002<\":/apploadbalancer/v1/loadBalancers/{load_balancer_id}:start'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*(\n\030StopLoadBalancerMetadata\022\014LoadBalancer\202\323\344\223\002;\"9/apploadbalancer/v1/loadBalancers/{load_balancer_id}:stop'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['AddListener']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['AddListener']._serialized_options = b'\262\322*#\n\023AddListenerMetadata\022\014LoadBalancer\202\323\344\223\002E\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addListener:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['RemoveListener']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['RemoveListener']._serialized_options = b'\262\322*&\n\026RemoveListenerMetadata\022\014LoadBalancer\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeListener:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['UpdateListener']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['UpdateListener']._serialized_options = b'\262\322*&\n\026UpdateListenerMetadata\022\014LoadBalancer\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateListener:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['AddSniMatch']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['AddSniMatch']._serialized_options = b'\262\322*,\n\023AddSniMatchMetadata\022\025google.protobuf.Empty\202\323\344\223\002E\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addSniMatch:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['UpdateSniMatch']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['UpdateSniMatch']._serialized_options = b'\262\322*/\n\026UpdateSniMatchMetadata\022\025google.protobuf.Empty\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateSniMatch:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['RemoveSniMatch']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['RemoveSniMatch']._serialized_options = b'\262\322*/\n\026RemoveSniMatchMetadata\022\025google.protobuf.Empty\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeSniMatch:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['GetTargetStates']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['GetTargetStates']._serialized_options = b'\202\323\344\223\002h\022f/apploadbalancer/v1/loadBalancers/{load_balancer_id}/targetStates/{backend_group_id}/{target_group_id}'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/apploadbalancer/v1/loadBalancers/{load_balancer_id}/operations'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['StartZonalShift']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['StartZonalShift']._serialized_options = b'\210\002\001\262\322*\'\n\027StartZonalShiftMetadata\022\014LoadBalancer\202\323\344\223\002I\"D/apploadbalancer/v1/loadBalancers/{load_balancer_id}:startZonalShift:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['CancelZonalShift']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['CancelZonalShift']._serialized_options = b'\210\002\001\262\322*(\n\030CancelZonalShiftMetadata\022\014LoadBalancer\202\323\344\223\002J\"E/apploadbalancer/v1/loadBalancers/{load_balancer_id}:cancelZonalShift:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['DisableZones']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['DisableZones']._serialized_options = b'\262\322*$\n\024DisableZonesMetadata\022\014LoadBalancer\202\323\344\223\002F\"A/apploadbalancer/v1/loadBalancers/{load_balancer_id}:disableZones:\001*'
  _globals['_LOADBALANCERSERVICE'].methods_by_name['EnableZones']._loaded_options = None
  _globals['_LOADBALANCERSERVICE'].methods_by_name['EnableZones']._serialized_options = b'\262\322*#\n\023EnableZonesMetadata\022\014LoadBalancer\202\323\344\223\002E\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:enableZones:\001*'
  _globals['_GETLOADBALANCERREQUEST']._serialized_start=397
  _globals['_GETLOADBALANCERREQUEST']._serialized_end=453
  _globals['_LISTLOADBALANCERSREQUEST']._serialized_start=456
  _globals['_LISTLOADBALANCERSREQUEST']._serialized_end=597
  _globals['_LISTLOADBALANCERSRESPONSE']._serialized_start=599
  _globals['_LISTLOADBALANCERSRESPONSE']._serialized_end=722
  _globals['_DELETELOADBALANCERREQUEST']._serialized_start=724
  _globals['_DELETELOADBALANCERREQUEST']._serialized_end=783
  _globals['_DELETELOADBALANCERMETADATA']._serialized_start=785
  _globals['_DELETELOADBALANCERMETADATA']._serialized_end=839
  _globals['_UPDATELOADBALANCERREQUEST']._serialized_start=842
  _globals['_UPDATELOADBALANCERREQUEST']._serialized_end=1588
  _globals['_UPDATELOADBALANCERREQUEST_LABELSENTRY']._serialized_start=1543
  _globals['_UPDATELOADBALANCERREQUEST_LABELSENTRY']._serialized_end=1588
  _globals['_UPDATELOADBALANCERMETADATA']._serialized_start=1590
  _globals['_UPDATELOADBALANCERMETADATA']._serialized_end=1644
  _globals['_CREATELOADBALANCERREQUEST']._serialized_start=1647
  _globals['_CREATELOADBALANCERREQUEST']._serialized_end=2388
  _globals['_CREATELOADBALANCERREQUEST_LABELSENTRY']._serialized_start=1543
  _globals['_CREATELOADBALANCERREQUEST_LABELSENTRY']._serialized_end=1588
  _globals['_CREATELOADBALANCERMETADATA']._serialized_start=2390
  _globals['_CREATELOADBALANCERMETADATA']._serialized_end=2444
  _globals['_STARTLOADBALANCERREQUEST']._serialized_start=2446
  _globals['_STARTLOADBALANCERREQUEST']._serialized_end=2504
  _globals['_STARTLOADBALANCERMETADATA']._serialized_start=2506
  _globals['_STARTLOADBALANCERMETADATA']._serialized_end=2559
  _globals['_STOPLOADBALANCERREQUEST']._serialized_start=2561
  _globals['_STOPLOADBALANCERREQUEST']._serialized_end=2618
  _globals['_STOPLOADBALANCERMETADATA']._serialized_start=2620
  _globals['_STOPLOADBALANCERMETADATA']._serialized_end=2672
  _globals['_ADDLISTENERREQUEST']._serialized_start=2675
  _globals['_ADDLISTENERREQUEST']._serialized_end=2803
  _globals['_ADDLISTENERMETADATA']._serialized_start=2805
  _globals['_ADDLISTENERMETADATA']._serialized_end=2875
  _globals['_REMOVELISTENERREQUEST']._serialized_start=2877
  _globals['_REMOVELISTENERREQUEST']._serialized_end=2952
  _globals['_REMOVELISTENERMETADATA']._serialized_start=2954
  _globals['_REMOVELISTENERMETADATA']._serialized_end=3027
  _globals['_UPDATELISTENERREQUEST']._serialized_start=3030
  _globals['_UPDATELISTENERREQUEST']._serialized_end=3210
  _globals['_UPDATELISTENERMETADATA']._serialized_start=3212
  _globals['_UPDATELISTENERMETADATA']._serialized_end=3285
  _globals['_ADDRESSSPEC']._serialized_start=3288
  _globals['_ADDRESSSPEC']._serialized_end=3611
  _globals['_EXTERNALIPV4ADDRESSSPEC']._serialized_start=3613
  _globals['_EXTERNALIPV4ADDRESSSPEC']._serialized_end=3655
  _globals['_INTERNALIPV4ADDRESSSPEC']._serialized_start=3657
  _globals['_INTERNALIPV4ADDRESSSPEC']._serialized_end=3718
  _globals['_EXTERNALIPV6ADDRESSSPEC']._serialized_start=3720
  _globals['_EXTERNALIPV6ADDRESSSPEC']._serialized_end=3762
  _globals['_ENDPOINTSPEC']._serialized_start=3764
  _globals['_ENDPOINTSPEC']._serialized_end=3889
  _globals['_LISTENERSPEC']._serialized_start=3892
  _globals['_LISTENERSPEC']._serialized_end=4249
  _globals['_GETTARGETSTATESREQUEST']._serialized_start=4251
  _globals['_GETTARGETSTATESREQUEST']._serialized_end=4370
  _globals['_GETTARGETSTATESRESPONSE']._serialized_start=4372
  _globals['_GETTARGETSTATESRESPONSE']._serialized_end=4466
  _globals['_ADDSNIMATCHREQUEST']._serialized_start=4469
  _globals['_ADDSNIMATCHREQUEST']._serialized_end=4668
  _globals['_ADDSNIMATCHMETADATA']._serialized_start=4670
  _globals['_ADDSNIMATCHMETADATA']._serialized_end=4764
  _globals['_REMOVESNIMATCHREQUEST']._serialized_start=4766
  _globals['_REMOVESNIMATCHREQUEST']._serialized_end=4880
  _globals['_REMOVESNIMATCHMETADATA']._serialized_start=4882
  _globals['_REMOVESNIMATCHMETADATA']._serialized_end=4979
  _globals['_UPDATESNIMATCHREQUEST']._serialized_start=4982
  _globals['_UPDATESNIMATCHREQUEST']._serialized_end=5233
  _globals['_UPDATESNIMATCHMETADATA']._serialized_start=5235
  _globals['_UPDATESNIMATCHMETADATA']._serialized_end=5332
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST']._serialized_start=5335
  _globals['_LISTLOADBALANCEROPERATIONSREQUEST']._serialized_end=5472
  _globals['_LISTLOADBALANCEROPERATIONSRESPONSE']._serialized_start=5474
  _globals['_LISTLOADBALANCEROPERATIONSRESPONSE']._serialized_end=5590
  _globals['_STARTZONALSHIFTREQUEST']._serialized_start=5592
  _globals['_STARTZONALSHIFTREQUEST']._serialized_end=5674
  _globals['_STARTZONALSHIFTMETADATA']._serialized_start=5676
  _globals['_STARTZONALSHIFTMETADATA']._serialized_end=5745
  _globals['_CANCELZONALSHIFTREQUEST']._serialized_start=5747
  _globals['_CANCELZONALSHIFTREQUEST']._serialized_end=5830
  _globals['_CANCELZONALSHIFTMETADATA']._serialized_start=5832
  _globals['_CANCELZONALSHIFTMETADATA']._serialized_end=5902
  _globals['_DISABLEZONESREQUEST']._serialized_start=5905
  _globals['_DISABLEZONESREQUEST']._serialized_end=6041
  _globals['_DISABLEZONESMETADATA']._serialized_start=6043
  _globals['_DISABLEZONESMETADATA']._serialized_end=6109
  _globals['_ENABLEZONESREQUEST']._serialized_start=6111
  _globals['_ENABLEZONESREQUEST']._serialized_end=6189
  _globals['_ENABLEZONESMETADATA']._serialized_start=6191
  _globals['_ENABLEZONESMETADATA']._serialized_end=6256
  _globals['_LOADBALANCERSERVICE']._serialized_start=6259
  _globals['_LOADBALANCERSERVICE']._serialized_end=10492
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.clouddesktop.v1 import disk_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/clouddesktop/v1/desktop_group.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/access/access.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/clouddesktop/v1/disk.proto\"\xd3\x07\n\x0c\x44\x65sktopGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x06status\x18\x04 \x01(\x0e\x32\x35.yandex.cloud.clouddesktop.v1.api.DesktopGroup.Status\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12G\n\x0eresources_spec\x18\x15 \x01(\x0b\x32/.yandex.cloud.clouddesktop.v1.api.ResourcesSpec\x12V\n\x16network_interface_spec\x18\x16 \x01(\x0b\x32\x36.yandex.cloud.clouddesktop.v1.api.NetworkInterfaceSpec\x12J\n\x06labels\x18\x17 \x03(\x0b\x32:.yandex.cloud.clouddesktop.v1.api.DesktopGroup.LabelsEntry\x12\x42\n\x0e\x62oot_disk_spec\x18\x18 \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12\x42\n\x0e\x64\x61ta_disk_spec\x18\x19 \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12Q\n\x0cgroup_config\x18\x1a \x01(\x0b\x32;.yandex.cloud.clouddesktop.v1.api.DesktopGroupConfiguration\x12P\n\x12\x61uto_update_policy\x18\x1b \x01(\x0b\x32\x32.yandex.cloud.clouddesktop.v1.api.AutoUpdatePolicyH\x00\x12T\n\x14manual_update_policy\x18\x1c \x01(\x0b\x32\x34.yandex.cloud.clouddesktop.v1.api.ManualUpdatePolicyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\x15\n\rupdate_policy\x12\x04\xc0\xc1\x31\x01J\x04\x08\r\x10\x15J\x04\x08\x05\x10\x0b\"\xd3\x02\n\x19\x44\x65sktopGroupConfiguration\x12%\n\x12min_ready_desktops\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12&\n\x13max_desktops_amount\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12]\n\x0c\x64\x65sktop_type\x18\x03 \x01(\x0e\x32G.yandex.cloud.clouddesktop.v1.api.DesktopGroupConfiguration.DesktopType\x12\x37\n\x07members\x18\x04 \x03(\x0b\x32\x1c.yandex.cloud.access.SubjectB\x08\x82\xc8\x31\x04\x30-10\"O\n\x0b\x44\x65sktopType\x12\x1c\n\x18\x44\x45SKTOP_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPERSISTENT\x10\x01\x12\x12\n\x0eNON_PERSISTENT\x10\x02\"b\n\rResourcesSpec\x12\x17\n\x06memory\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"`\n\x14NetworkInterfaceSpec\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\nsubnet_ids\x18\x02 \x03(\tB\x12\x82\xc8\x31\x02>0\x8a\xc8\x31\x04<=50\x90\xc8\x31\x01\"\x14\n\x12ManualUpdatePolicy\"\x12\n\x10\x41utoUpdatePolicyBq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_DESKTOPGROUP_LABELSENTRY']._loaded_options = None
  _globals['_DESKTOPGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DESKTOPGROUP'].oneofs_by_name['update_policy']._loaded_options = None
  _globals['_DESKTOPGROUP'].oneofs_by_name['update_policy']._serialized_options = b'\300\3011\001'
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['min_ready_desktops']._loaded_options = None
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['min_ready_desktops']._serialized_options = b'\372\3071\0051-512'
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['max_desktops_amount']._loaded_options = None
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['max_desktops_amount']._serialized_options = b'\372\3071\0050-512'
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['members']._loaded_options = None
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['members']._serialized_options = b'\202\3101\0040-10'
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._serialized_options = b'\372\3071\0050-100'
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['network_id']._loaded_options = None
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['subnet_ids']._serialized_options = b'\202\3101\002>0\212\3101\004<=50\220\3101\001'
  _globals['_DESKTOPGROUP']._serialized_start=226
  _globals['_DESKTOPGROUP']._serialized_end=1205
  _globals['_DESKTOPGROUP_LABELSENTRY']._serialized_start=1051
  _globals['_DESKTOPGROUP_LABELSENTRY']._serialized_end=1096
  _globals['_DESKTOPGROUP_STATUS']._serialized_start=1098
  _globals['_DESKTOPGROUP_STATUS']._serialized_end=1170
  _globals['_DESKTOPGROUPCONFIGURATION']._serialized_start=1208
  _globals['_DESKTOPGROUPCONFIGURATION']._serialized_end=1547
  _globals['_DESKTOPGROUPCONFIGURATION_DESKTOPTYPE']._serialized_start=1468
  _globals['_DESKTOPGROUPCONFIGURATION_DESKTOPTYPE']._serialized_end=1547
  _globals['_RESOURCESSPEC']._serialized_start=1549
  _globals['_RESOURCESSPEC']._serialized_end=1647
  _globals['_NETWORKINTERFACESPEC']._serialized_start=1649
  _globals['_NETWORKINTERFACESPEC']._serialized_end=1745
  _globals['_MANUALUPDATEPOLICY']._serialized_start=1747
  _globals['_MANUALUPDATEPOLICY']._serialized_end=1767
  _globals['_AUTOUPDATEPOLICY']._serialized_start=1769
  _globals['_AUTOUPDATEPOLICY']._serialized_end=1787
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/gitlab/v1/instance_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/gitlab/v1/instance_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.gitlab.v1 import instance_pb2 as yandex_dot_cloud_dot_gitlab_dot_v1_dot_instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/gitlab/v1/instance_service.proto\x12\x16yandex.cloud.gitlab.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a%yandex/cloud/gitlab/v1/instance.proto\"7\n\x12GetInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x14ListInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"e\n\x15ListInstancesResponse\x12\x33\n\tinstances\x18\x01 \x03(\x0b\x32 .yandex.cloud.gitlab.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xcf\x05\n\x15\x43reateInstanceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.gitlab.v1.CreateInstanceRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12(\n\x12resource_preset_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\tdisk_size\x18\x06 \x01(\x03\x12!\n\x0b\x61\x64min_login\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x0b\x61\x64min_email\x18\x08 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x46\n\rdomain_prefix\x18\t \x01(\tB/\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z0-9][a-z0-9-]{3,48}[a-z0-9]\x8a\xc8\x31\x04<=50\x12\x1f\n\tsubnet_id\x18\n \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\'\n\x19\x62\x61\x63kup_retain_period_days\x18\x0c \x01(\x03\x42\x04\xe8\xc7\x31\x00\x12#\n\x1bmaintenance_delete_untagged\x18\x0e \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x0f \x01(\x08\x12\'\n\x11\x61pproval_rules_id\x18\x13 \x01(\tB\x0c\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=30\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0b\x10\x0cJ\x04\x08\r\x10\x0eJ\x04\x08\x10\x10\x13\"-\n\x16\x43reateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\xee\x04\n\x15UpdateInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.gitlab.v1.UpdateInstanceRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12!\n\x19\x62\x61\x63kup_retain_period_days\x18\x06 \x01(\x03\x12\x1a\n\x12resource_preset_id\x18\x07 \x01(\t\x12#\n\x1bmaintenance_delete_untagged\x18\n \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x0b \x01(\x08\x12#\n\x11\x61pproval_rules_id\x18\x0c \x01(\tB\x08\x8a\xc8\x31\x04<=30\x12\'\n\x14\x61pproval_rules_token\x18\r \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x11\n\tdisk_size\x18\x15 \x01(\x03\x12/\n\x0bupdate_mask\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x06J\x04\x08\x08\x10\nJ\x04\x08\x0e\x10\x15J\x04\x08\x16\x10\x18\"-\n\x16UpdateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\",\n\x15\x44\x65leteInstanceRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"-\n\x16\x44\x65leteInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"+\n\x14StartInstanceRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\",\n\x15StartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"*\n\x13StopInstanceRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"+\n\x14StopInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t2\x88\t\n\x0fInstanceService\x12\x7f\n\x03Get\x12*.yandex.cloud.gitlab.v1.GetInstanceRequest\x1a .yandex.cloud.gitlab.v1.Instance\"*\x82\xd3\xe4\x93\x02$\x12\"/gitlab/v1/instances/{instance_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.gitlab.v1.ListInstancesRequest\x1a-.yandex.cloud.gitlab.v1.ListInstancesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/gitlab/v1/instances\x12\xa1\x01\n\x06\x43reate\x12-.yandex.cloud.gitlab.v1.CreateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"E\xb2\xd2*\"\n\x16\x43reateInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\x19\"\x14/gitlab/v1/instances:\x01*\x12\xaf\x01\n\x06Update\x12-.yandex.cloud.gitlab.v1.UpdateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*\"\n\x16UpdateInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02\'2\"/gitlab/v1/instances/{instance_id}:\x01*\x12\xb9\x01\n\x06\x44\x65lete\x12-.yandex.cloud.gitlab.v1.DeleteInstanceRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*/\n\x16\x44\x65leteInstanceMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/gitlab/v1/instances/{instance_id}\x12\xaf\x01\n\x05Start\x12,.yandex.cloud.gitlab.v1.StartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*!\n\x15StartInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02*\"(/gitlab/v1/instances/{instance_id}:start\x12\xab\x01\n\x04Stop\x12+.yandex.cloud.gitlab.v1.StopInstanceRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x14StopInstanceMetadata\x12\x08Instance\x82\xd3\xe4\x93\x02)\"\'/gitlab/v1/instances/{instance_id}:stopBd\n\x1ayandex.cloud.api.gitlab.v1B\x03GISZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlabb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.gitlab.v1.instance_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.gitlab.v1B\003GISZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlab'
  _globals['_GETINSTANCEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_GETINSTANCEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTINSTANCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTINSTANCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTINSTANCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTINSTANCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTINSTANCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTINSTANCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEINSTANCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['resource_preset_id']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['admin_login']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['admin_login']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['admin_email']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['admin_email']._serialized_options = b'\350\3071\001'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['domain_prefix']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['domain_prefix']._serialized_options = b'\350\3071\001\362\3071\037[a-z0-9][a-z0-9-]{3,48}[a-z0-9]\212\3101\004<=50'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['backup_retain_period_days']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['backup_retain_period_days']._serialized_options = b'\350\3071\000'
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['approval_rules_id']._loaded_options = None
  _globals['_CREATEINSTANCEREQUEST'].fields_by_name['approval_rules_id']._serialized_options = b'\350\3071\000\212\3101\004<=30'
  _globals['_UPDATEINSTANCEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['approval_rules_id']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['approval_rules_id']._serialized_options = b'\212\3101\004<=30'
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['approval_rules_token']._loaded_options = None
  _globals['_UPDATEINSTANCEREQUEST'].fields_by_name['approval_rules_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_INSTANCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/gitlab/v1/instances/{instance_id}'
  _globals['_INSTANCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/gitlab/v1/instances'
  _globals['_INSTANCESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateInstanceMetadata\022\010Instance\202\323\344\223\002\031\"\024/gitlab/v1/instances:\001*'
  _globals['_INSTANCESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateInstanceMetadata\022\010Instance\202\323\344\223\002\'2\"/gitlab/v1/instances/{instance_id}:\001*'
  _globals['_INSTANCESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteInstanceMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/gitlab/v1/instances/{instance_id}'
  _globals['_INSTANCESERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*!\n\025StartInstanceMetadata\022\010Instance\202\323\344\223\002*\"(/gitlab/v1/instances/{instance_id}:start'
  _globals['_INSTANCESERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_INSTANCESERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322* \n\024StopInstanceMetadata\022\010Instance\202\323\344\223\002)\"\'/gitlab/v1/instances/{instance_id}:stop'
  _globals['_GETINSTANCEREQUEST']._serialized_start=281
  _globals['_GETINSTANCEREQUEST']._serialized_end=336
  _globals['_LISTINSTANCESREQUEST']._serialized_start=338
  _globals['_LISTINSTANCESREQUEST']._serialized_end=455
  _globals['_LISTINSTANCESRESPONSE']._serialized_start=457
  _globals['_LISTINSTANCESRESPONSE']._serialized_end=558
  _globals['_CREATEINSTANCEREQUEST']._serialized_start=561
  _globals['_CREATEINSTANCEREQUEST']._serialized_end=1280
  _globals['_CREATEINSTANCEREQUEST_LABELSENTRY']._serialized_start=1217
  _globals['_CREATEINSTANCEREQUEST_LABELSENTRY']._serialized_end=1262
  _globals['_CREATEINSTANCEMETADATA']._serialized_start=1282
  _globals['_CREATEINSTANCEMETADATA']._serialized_end=1327
  _globals['_UPDATEINSTANCEREQUEST']._serialized_start=1330
  _globals['_UPDATEINSTANCEREQUEST']._serialized_end=1952
  _globals['_UPDATEINSTANCEREQUEST_LABELSENTRY']._serialized_start=1217
  _globals['_UPDATEINSTANCEREQUEST_LABELSENTRY']._serialized_end=1262
  _globals['_UPDATEINSTANCEMETADATA']._serialized_start=1954
  _globals['_UPDATEINSTANCEMETADATA']._serialized_end=1999
  _globals['_DELETEINSTANCEREQUEST']._serialized_start=2001
  _globals['_DELETEINSTANCEREQUEST']._serialized_end=2045
  _globals['_DELETEINSTANCEMETADATA']._serialized_start=2047
  _globals['_DELETEINSTANCEMETADATA']._serialized_end=2092
  _globals['_STARTINSTANCEREQUEST']._serialized_start=2094
  _globals['_STARTINSTANCEREQUEST']._serialized_end=2137
  _globals['_STARTINSTANCEMETADATA']._serialized_start=2139
  _globals['_STARTINSTANCEMETADATA']._serialized_end=2183
  _globals['_STOPINSTANCEREQUEST']._serialized_start=2185
  _globals['_STOPINSTANCEREQUEST']._serialized_end=2227
  _globals['_STOPINSTANCEMETADATA']._serialized_start=2229
  _globals['_STOPINSTANCEMETADATA']._serialized_end=2272
  _globals['_INSTANCESERVICE']._serialized_start=2275
  _globals['_INSTANCESERVICE']._serialized_end=3435
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.oauth_client_secret_pb2
import yandex.cloud.iam.v1.oauth_client_secret_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OAuthClientSecretServiceStub:
    """A set of methods for managing OAuthClientSecret resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.GetOAuthClientSecretRequest,
        yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret,
    ]
    """Returns the sepcified OAuthClientSecret resource.

    To get the list of available OAuthClientSecret resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsRequest,
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse,
    ]
    """Retrieves the list of OAuthClientSecret resources of the specified OAuthClient."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.CreateOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuthClientSecret resource for the specified OAuthClient."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.DeleteOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuthClientSecret resource."""

class OAuthClientSecretServiceAsyncStub:
    """A set of methods for managing OAuthClientSecret resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.GetOAuthClientSecretRequest,
        yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret,
    ]
    """Returns the sepcified OAuthClientSecret resource.

    To get the list of available OAuthClientSecret resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsRequest,
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse,
    ]
    """Retrieves the list of OAuthClientSecret resources of the specified OAuthClient."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.CreateOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuthClientSecret resource for the specified OAuthClient."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.DeleteOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuthClientSecret resource."""

class OAuthClientSecretServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing OAuthClientSecret resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.GetOAuthClientSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret, collections.abc.Awaitable[yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret]]:
        """Returns the sepcified OAuthClientSecret resource.

        To get the list of available OAuthClientSecret resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse]]:
        """Retrieves the list of OAuthClientSecret resources of the specified OAuthClient."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.CreateOAuthClientSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an OAuthClientSecret resource for the specified OAuthClient."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.DeleteOAuthClientSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified OAuthClientSecret resource."""

def add_OAuthClientSecretServiceServicer_to_server(servicer: OAuthClientSecretServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.runs.run_pb2
import yandex.cloud.ai.assistants.v1.runs.run_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RunServiceStub:
    """RunService provides operations for managing runs."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.CreateRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]
    """Create a new run for a given assistant and thread."""

    Listen: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListenRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent,
    ]
    """Listen to events from a specific run.
    If the run was created with `stream = false`, Listen will only respond with the final status of the run
    and will not stream partial messages or intermediate events.
    """

    Attach: grpc.StreamStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.AttachRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent,
    ]
    """Bi-directional streaming method to interact with a specific run.
    Like `Listen`, `Attach` streams events from the run, but also allows clients to send events back.
    For example, it can be used to submit function call results when the run is waiting for user input.
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]
    """Retrieve details of a specific run by its ID."""

    GetLastByThread: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetLastRunByThreadRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]
    """Retrieves the most recent run for a specific thread."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse,
    ]
    """List runs in a specific folder."""

    Submit: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunResponse,
    ]
    """Submit event to run
    For example, submit function call results when the run is waiting for user input.
    """

class RunServiceAsyncStub:
    """RunService provides operations for managing runs."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.CreateRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]
    """Create a new run for a given assistant and thread."""

    Listen: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListenRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent,
    ]
    """Listen to events from a specific run.
    If the run was created with `stream = false`, Listen will only respond with the final status of the run
    and will not stream partial messages or intermediate events.
    """

    Attach: grpc.aio.StreamStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.AttachRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent,
    ]
    """Bi-directional streaming method to interact with a specific run.
    Like `Listen`, `Attach` streams events from the run, but also allows clients to send events back.
    For example, it can be used to submit function call results when the run is waiting for user input.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]
    """Retrieve details of a specific run by its ID."""

    GetLastByThread: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetLastRunByThreadRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]
    """Retrieves the most recent run for a specific thread."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse,
    ]
    """List runs in a specific folder."""

    Submit: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunResponse,
    ]
    """Submit event to run
    For example, submit function call results when the run is waiting for user input.
    """

class RunServiceServicer(metaclass=abc.ABCMeta):
    """RunService provides operations for managing runs."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.CreateRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]]:
        """Create a new run for a given assistant and thread."""

    @abc.abstractmethod
    def Listen(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListenRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent], collections.abc.AsyncIterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent]]:
        """Listen to events from a specific run.
        If the run was created with `stream = false`, Listen will only respond with the final status of the run
        and will not stream partial messages or intermediate events.
        """

    @abc.abstractmethod
    def Attach(
        self,
        request_iterator: _MaybeAsyncIterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.AttachRunRequest],
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent], collections.abc.AsyncIterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent]]:
        """Bi-directional streaming method to interact with a specific run.
        Like `Listen`, `Attach` streams events from the run, but also allows clients to send events back.
        For example, it can be used to submit function call results when the run is waiting for user input.
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]]:
        """Retrieve details of a specific run by its ID."""

    @abc.abstractmethod
    def GetLastByThread(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetLastRunByThreadRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]]:
        """Retrieves the most recent run for a specific thread."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse]]:
        """List runs in a specific folder."""

    @abc.abstractmethod
    def Submit(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.SubmitToRunResponse]]:
        """Submit event to run
        For example, submit function call results when the run is waiting for user input.
        """

def add_RunServiceServicer_to_server(servicer: RunServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/v1/billable_object.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/v1/billable_object.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/billing/v1/billable_object.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"*\n\x0e\x42illableObject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x8d\x01\n\x15\x42illableObjectBinding\x12\x32\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x0f\x62illable_object\x18\x02 \x01(\x0b\x32\'.yandex.cloud.billing.v1.BillableObjectBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.billable_object_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _globals['_BILLABLEOBJECT']._serialized_start=107
  _globals['_BILLABLEOBJECT']._serialized_end=149
  _globals['_BILLABLEOBJECTBINDING']._serialized_start=152
  _globals['_BILLABLEOBJECTBINDING']._serialized_end=293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/multi_source_chart_widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/multi_source_chart_widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.monitoring.v3 import downsampling_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_downsampling__pb2
from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2
from yandex.cloud.monitoring.v3 import thresholds_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_thresholds__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/monitoring/v3/multi_source_chart_widget.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/monitoring/v3/downsampling.proto\x1a,yandex/cloud/monitoring/v3/unit_format.proto\x1a+yandex/cloud/monitoring/v3/thresholds.proto\"\x8f\x38\n\x16MultiSourceChartWidget\x12\n\n\x02id\x18\x01 \x01(\t\x12J\n\x07targets\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.monitoring.v3.MultiSourceChartWidget.Target\x12S\n\x0c\x64\x61ta_sources\x18\x03 \x03(\x0b\x32=.yandex.cloud.monitoring.v3.MultiSourceChartWidget.DataSource\x12h\n\x16visualization_settings\x18\x04 \x01(\x0b\x32H.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings\x12\\\n\x10series_overrides\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides\x12\x63\n\x14name_hiding_settings\x18\x06 \x01(\x0b\x32\x45.yandex.cloud.monitoring.v3.MultiSourceChartWidget.NameHidingSettings\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12\x16\n\x0e\x64isplay_legend\x18\t \x01(\x08\x12Q\n\x06\x66reeze\x18\n \x01(\x0e\x32\x41.yandex.cloud.monitoring.v3.MultiSourceChartWidget.FreezeDuration\x12Q\n\x06repeat\x18\x0b \x01(\x0b\x32\x41.yandex.cloud.monitoring.v3.MultiSourceChartWidget.RepeatSettings\x12:\n\nthresholds\x18\x0c \x01(\x0b\x32&.yandex.cloud.monitoring.v3.Thresholds\x1a\xe1\x03\n\x06Target\x12g\n\x11monitoring_target\x18\x01 \x01(\x0b\x32J.yandex.cloud.monitoring.v3.MultiSourceChartWidget.Target.MonitoringTargetH\x00\x12g\n\x11prometheus_target\x18\x02 \x01(\x0b\x32J.yandex.cloud.monitoring.v3.MultiSourceChartWidget.Target.PrometheusTargetH\x00\x1aj\n\x10MonitoringTarget\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x11\n\ttext_mode\x18\x03 \x01(\x08\x12\x0e\n\x06hidden\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a\x8e\x01\n\x10PrometheusTarget\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x11\n\ttext_mode\x18\x04 \x01(\x08\x12\x0e\n\x06hidden\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04step\x18\x07 \x01(\tB\x08\n\x06target\x1a\x9d\x03\n\nDataSource\x12t\n\x16monitoring_data_source\x18\x01 \x01(\x0b\x32R.yandex.cloud.monitoring.v3.MultiSourceChartWidget.DataSource.MonitoringDataSourceH\x00\x12t\n\x16prometheus_data_source\x18\x02 \x01(\x0b\x32R.yandex.cloud.monitoring.v3.MultiSourceChartWidget.DataSource.PrometheusDataSourceH\x00\x1a\x62\n\x14MonitoringDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12>\n\x0c\x64ownsampling\x18\x02 \x01(\x0b\x32(.yandex.cloud.monitoring.v3.Downsampling\x1a\x30\n\x14PrometheusDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04step\x18\x02 \x01(\x03\x42\r\n\x0b\x64\x61ta_source\x1a\xd5\x1a\n\x15VisualizationSettings\x12h\n\x04type\x18\x01 \x01(\x0e\x32Z.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.VisualizationType\x12\x11\n\tnormalize\x18\x02 \x01(\x08\x12i\n\x0binterpolate\x18\x03 \x01(\x0e\x32T.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.Interpolate\x12o\n\x0b\x61ggregation\x18\x04 \x01(\x0e\x32Z.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.SeriesAggregation\x12{\n\x15\x63olor_scheme_settings\x18\x05 \x01(\x0b\x32\\.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings\x12r\n\x10heatmap_settings\x18\x06 \x01(\x0b\x32X.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.HeatmapSettings\x12n\n\x0eyaxis_settings\x18\x07 \x01(\x0b\x32V.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.YaxisSettings\x12\r\n\x05title\x18\x08 \x01(\t\x12\x13\n\x0bshow_labels\x18\t \x01(\x08\x1a\xe0\n\n\x13\x43olorSchemeSettings\x12\x86\x01\n\tautomatic\x18\x01 \x01(\x0b\x32q.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorSchemeH\x00\x12\x84\x01\n\x08standard\x18\x02 \x01(\x0b\x32p.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorSchemeH\x00\x12\x84\x01\n\x08gradient\x18\x03 \x01(\x0b\x32p.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorSchemeH\x00\x12|\n\x04hash\x18\x04 \x01(\x0b\x32l.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorSchemeH\x00\x12\x88\x01\n\nthresholds\x18\x05 \x01(\x0b\x32r.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorSchemeH\x00\x12\x84\x01\n\x08\x63onstant\x18\x06 \x01(\x0b\x32p.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.ConstantColorSchemeH\x00\x1a\x16\n\x14\x41utomaticColorScheme\x1a\x15\n\x13StandardColorScheme\x1ai\n\x13GradientColorScheme\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\x11\n\x0fHashColorScheme\x1a$\n\x13\x43onstantColorScheme\x12\r\n\x05\x63olor\x18\x01 \x01(\t\x1a\xc4\x02\n\x15ThresholdsColorScheme\x12\x93\x01\n\x0b\x61ggregation\x18\x01 \x01(\x0e\x32~.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation\"\x94\x01\n\x0b\x41ggregation\x12\x1b\n\x17\x41GGREGATION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41GGREGATION_LAST\x10\x01\x12\x13\n\x0f\x41GGREGATION_MIN\x10\x02\x12\x13\n\x0f\x41GGREGATION_MAX\x10\x03\x12\x13\n\x0f\x41GGREGATION_AVG\x10\x04\x12\x13\n\x0f\x41GGREGATION_SUM\x10\x05\x42\x08\n\x06scheme\x1a\x65\n\x0fHeatmapSettings\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\xff\x01\n\x05Yaxis\x12`\n\x04type\x18\x01 \x01(\x0e\x32R.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.YaxisType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03min\x18\x03 \x01(\t\x12\x0b\n\x03max\x18\x04 \x01(\t\x12;\n\x0bunit_format\x18\x05 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\x12.\n\tprecision\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\xcc\x01\n\rYaxisSettings\x12\\\n\x04left\x18\x01 \x01(\x0b\x32N.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.Yaxis\x12]\n\x05right\x18\x02 \x01(\x0b\x32N.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.Yaxis\"\xae\x02\n\x11VisualizationType\x12\"\n\x1eVISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17VISUALIZATION_TYPE_LINE\x10\x01\x12\x1c\n\x18VISUALIZATION_TYPE_STACK\x10\x02\x12\x1d\n\x19VISUALIZATION_TYPE_COLUMN\x10\x03\x12\x1d\n\x19VISUALIZATION_TYPE_POINTS\x10\x04\x12\x1a\n\x16VISUALIZATION_TYPE_PIE\x10\x05\x12\x1b\n\x17VISUALIZATION_TYPE_BARS\x10\x06\x12#\n\x1fVISUALIZATION_TYPE_DISTRIBUTION\x10\x07\x12\x1e\n\x1aVISUALIZATION_TYPE_HEATMAP\x10\x08\"o\n\x0bInterpolate\x12\x1b\n\x17INTERPOLATE_UNSPECIFIED\x10\x00\x12\x16\n\x12INTERPOLATE_LINEAR\x10\x01\x12\x14\n\x10INTERPOLATE_LEFT\x10\x02\x12\x15\n\x11INTERPOLATE_RIGHT\x10\x03\"Z\n\tYaxisType\x12\x1a\n\x16YAXIS_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11YAXIS_TYPE_LINEAR\x10\x01\x12\x1a\n\x16YAXIS_TYPE_LOGARITHMIC\x10\x02\"\xc4\x01\n\x11SeriesAggregation\x12\"\n\x1eSERIES_AGGREGATION_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERIES_AGGREGATION_AVG\x10\x01\x12\x1a\n\x16SERIES_AGGREGATION_MIN\x10\x02\x12\x1a\n\x16SERIES_AGGREGATION_MAX\x10\x03\x12\x1b\n\x17SERIES_AGGREGATION_LAST\x10\x04\x12\x1a\n\x16SERIES_AGGREGATION_SUM\x10\x05\x1a\x83\t\n\x0fSeriesOverrides\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\x16\n\x0ctarget_index\x18\x02 \x01(\tH\x00\x12k\n\x08settings\x18\x03 \x01(\x0b\x32Y.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.SeriesOverrideSettings\x12\x15\n\roverride_name\x18\x04 \x01(\t\x12S\n\x07matcher\x18\x05 \x01(\x0b\x32\x42.yandex.cloud.monitoring.v3.MultiSourceChartWidget.OverrideMatcher\x1a\xa6\x04\n\x16SeriesOverrideSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12h\n\x04type\x18\x03 \x01(\x0e\x32Z.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType\x12\x12\n\nstack_name\x18\x04 \x01(\t\x12\x11\n\tgrow_down\x18\x05 \x01(\x08\x12h\n\x0eyaxis_position\x18\x06 \x01(\x0e\x32P.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.YaxisPosition\x12\x12\n\nline_width\x18\x07 \x01(\x03\x12w\n\nline_style\x18\x08 \x01(\x0e\x32\x63.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle\"g\n\tLineStyle\x12\x1a\n\x16LINE_STYLE_UNSPECIFIED\x10\x00\x12\x14\n\x10LINE_STYLE_SOLID\x10\x01\x12\x13\n\x0fLINE_STYLE_DASH\x10\x02\x12\x13\n\x0fLINE_STYLE_DOTS\x10\x03\"b\n\rYaxisPosition\x12\x1e\n\x1aYAXIS_POSITION_UNSPECIFIED\x10\x00\x12\x17\n\x13YAXIS_POSITION_LEFT\x10\x01\x12\x18\n\x14YAXIS_POSITION_RIGHT\x10\x02\"\xd9\x01\n\x17SeriesVisualizationType\x12)\n%SERIES_VISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eSERIES_VISUALIZATION_TYPE_LINE\x10\x01\x12#\n\x1fSERIES_VISUALIZATION_TYPE_STACK\x10\x02\x12$\n SERIES_VISUALIZATION_TYPE_COLUMN\x10\x03\x12$\n SERIES_VISUALIZATION_TYPE_POINTS\x10\x04\x42\x06\n\x04type\x1a\xe2\x02\n\x0fOverrideMatcher\x12P\n\x05query\x18\x01 \x01(\x0b\x32?.yandex.cloud.monitoring.v3.MultiSourceChartWidget.QueryMatcherH\x00\x12N\n\x04line\x18\x02 \x01(\x0b\x32>.yandex.cloud.monitoring.v3.MultiSourceChartWidget.LineMatcherH\x00\x12R\n\x06regexp\x18\x03 \x01(\x0b\x32@.yandex.cloud.monitoring.v3.MultiSourceChartWidget.RegExpMatcherH\x00\x12Q\n\x06values\x18\x04 \x01(\x0b\x32?.yandex.cloud.monitoring.v3.MultiSourceChartWidget.ValueMatcherH\x00\x42\x06\n\x04type\x1a\x1d\n\x0cQueryMatcher\x12\r\n\x05names\x18\x01 \x03(\t\x1a\x1f\n\x0bLineMatcher\x12\x10\n\x08line_ids\x18\x01 \x03(\t\x1a \n\rRegExpMatcher\x12\x0f\n\x07reg_exp\x18\x01 \x01(\t\x1a\x61\n\x0cValueMatcher\x12Q\n\nvalue_type\x18\x01 \x01(\x0e\x32=.yandex.cloud.monitoring.v3.MultiSourceChartWidget.ValuesType\x1a\x35\n\x12NameHidingSettings\x12\x10\n\x08positive\x18\x01 \x01(\x08\x12\r\n\x05names\x18\x02 \x03(\t\x1a>\n\x0eRepeatSettings\x12\x11\n\trepeat_by\x18\x01 \x03(\t\x12\x19\n\x11max_charts_in_row\x18\x02 \x01(\x03\"^\n\nValuesType\x12\x1b\n\x17VALUES_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15VALUES_TYPE_ALL_ZEROS\x10\x01\x12\x18\n\x14VALUES_TYPE_ALL_NULL\x10\x02\"\x99\x01\n\x0e\x46reezeDuration\x12\x1f\n\x1b\x46REEZE_DURATION_UNSPECIFIED\x10\x00\x12\x18\n\x14\x46REEZE_DURATION_HOUR\x10\x01\x12\x17\n\x13\x46REEZE_DURATION_DAY\x10\x02\x12\x18\n\x14\x46REEZE_DURATION_WEEK\x10\x03\x12\x19\n\x15\x46REEZE_DURATION_MONTH\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.multi_source_chart_widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_MULTISOURCECHARTWIDGET']._serialized_start=261
  _globals['_MULTISOURCECHARTWIDGET']._serialized_end=7444
  _globals['_MULTISOURCECHARTWIDGET_TARGET']._serialized_start=1048
  _globals['_MULTISOURCECHARTWIDGET_TARGET']._serialized_end=1529
  _globals['_MULTISOURCECHARTWIDGET_TARGET_MONITORINGTARGET']._serialized_start=1268
  _globals['_MULTISOURCECHARTWIDGET_TARGET_MONITORINGTARGET']._serialized_end=1374
  _globals['_MULTISOURCECHARTWIDGET_TARGET_PROMETHEUSTARGET']._serialized_start=1377
  _globals['_MULTISOURCECHARTWIDGET_TARGET_PROMETHEUSTARGET']._serialized_end=1519
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE']._serialized_start=1532
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE']._serialized_end=1945
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_MONITORINGDATASOURCE']._serialized_start=1782
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_MONITORINGDATASOURCE']._serialized_end=1880
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_PROMETHEUSDATASOURCE']._serialized_start=1882
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_PROMETHEUSDATASOURCE']._serialized_end=1930
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS']._serialized_start=1948
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS']._serialized_end=5361
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS']._serialized_start=2708
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS']._serialized_end=4084
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME']._serialized_start=3538
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME']._serialized_end=3560
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME']._serialized_start=3562
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME']._serialized_end=3583
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME']._serialized_start=3585
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME']._serialized_end=3690
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_HASHCOLORSCHEME']._serialized_start=3692
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_HASHCOLORSCHEME']._serialized_end=3709
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_CONSTANTCOLORSCHEME']._serialized_start=3711
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_CONSTANTCOLORSCHEME']._serialized_end=3747
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME']._serialized_start=3750
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME']._serialized_end=4074
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME_AGGREGATION']._serialized_start=3926
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME_AGGREGATION']._serialized_end=4074
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS']._serialized_start=4086
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS']._serialized_end=4187
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS']._serialized_start=4190
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS']._serialized_end=4445
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS']._serialized_start=4448
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS']._serialized_end=4652
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE']._serialized_start=4655
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE']._serialized_end=4957
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE']._serialized_start=4959
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE']._serialized_end=5070
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE']._serialized_start=5072
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE']._serialized_end=5162
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION']._serialized_start=5165
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION']._serialized_end=5361
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES']._serialized_start=5364
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES']._serialized_end=6519
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS']._serialized_start=5641
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS']._serialized_end=6191
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS_LINESTYLE']._serialized_start=6088
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS_LINESTYLE']._serialized_end=6191
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION']._serialized_start=6193
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION']._serialized_end=6291
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE']._serialized_start=6294
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE']._serialized_end=6511
  _globals['_MULTISOURCECHARTWIDGET_OVERRIDEMATCHER']._serialized_start=6522
  _globals['_MULTISOURCECHARTWIDGET_OVERRIDEMATCHER']._serialized_end=6876
  _globals['_MULTISOURCECHARTWIDGET_QUERYMATCHER']._serialized_start=6878
  _globals['_MULTISOURCECHARTWIDGET_QUERYMATCHER']._serialized_end=6907
  _globals['_MULTISOURCECHARTWIDGET_LINEMATCHER']._serialized_start=6909
  _globals['_MULTISOURCECHARTWIDGET_LINEMATCHER']._serialized_end=6940
  _globals['_MULTISOURCECHARTWIDGET_REGEXPMATCHER']._serialized_start=6942
  _globals['_MULTISOURCECHARTWIDGET_REGEXPMATCHER']._serialized_end=6974
  _globals['_MULTISOURCECHARTWIDGET_VALUEMATCHER']._serialized_start=6976
  _globals['_MULTISOURCECHARTWIDGET_VALUEMATCHER']._serialized_end=7073
  _globals['_MULTISOURCECHARTWIDGET_NAMEHIDINGSETTINGS']._serialized_start=7075
  _globals['_MULTISOURCECHARTWIDGET_NAMEHIDINGSETTINGS']._serialized_end=7128
  _globals['_MULTISOURCECHARTWIDGET_REPEATSETTINGS']._serialized_start=7130
  _globals['_MULTISOURCECHARTWIDGET_REPEATSETTINGS']._serialized_end=7192
  _globals['_MULTISOURCECHARTWIDGET_VALUESTYPE']._serialized_start=7194
  _globals['_MULTISOURCECHARTWIDGET_VALUESTYPE']._serialized_end=7288
  _globals['_MULTISOURCECHARTWIDGET_FREEZEDURATION']._serialized_start=7291
  _globals['_MULTISOURCECHARTWIDGET_FREEZEDURATION']._serialized_end=7444
# @@protoc_insertion_point(module_scope)
